@@ -1,7 +1,5 @@
 package Business::OnlinePayment;
 
-# $Id: OnlinePayment.pm,v 1.7 1999/10/01 18:37:26 robobob Exp $
-
 use strict;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $AUTOLOAD);
 
@@ -11,7 +9,9 @@ require Exporter;
 @ISA = qw(Exporter AutoLoader);
 @EXPORT = qw();
 @EXPORT_OK = qw();
-( $VERSION ) = '$Revision: 1.7 $ ' =~ /\$Revision:\s+([^\s]+)/;
+
+$VERSION = do { my @r=(q$Revision: 2.1 $=~/\d+/g);sprintf "%d."."%02d"x$#r,@r};
+
 use Carp();
 
 my %fields = (
@@ -304,7 +304,7 @@ Retrieve or change the processor submission path (CHANGE AT YOUR OWN RISK).
 
 =head1 AUTHOR
 
-Jason S Kohles, jason@mediabang.com
+Jason Kohles, email@jasonkohles.com
 
 =head1 DISCLAIMER
 
